==> ifk-smhi-0.1.0.tar.gz: ifk-smhi-0.1.0/README.md <==
<h1 align="center">ifk-smhi</h1>

<p align="center">
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml/badge.svg?branch=main" alt="build" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml">
        <img src="https://img.shields.io/endpoint?logo=github&labelColor=%23333a41&logoColor=%23959da5&url=https://gist.githubusercontent.com/mgcth/2d8de651f24d184f5ebe101ffc3c9527/raw/ifk-smhi-coverage-badge.json" alt="coverage" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-docs.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-docs.yaml/badge.svg?branch=main" alt="docs" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-lint.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-lint.yaml/badge.svg?branch=main" alt="lint" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-type.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-type.yaml/badge.svg?branch=main" alt="type" style="max-width: 100%;">
    </a>
</p>

<p align="center">
    <a href="https://www.python.org">
        <img src="https://img.shields.io/badge/Python-3.9%20|%203.10-blue" alt="Python: 3.9 | 3.10 | 3.11" style="max-width: 100%;">
    </a>
    <a href="https://pytest.org">
        <img src="https://img.shields.io/badge/Testing_framework-pytest-a04000" alt="Testing framework: pytest" style="max-width: 100%;">
    </a>
    <a href="hhttps://flake8.pycqa.org">
        <img src="https://img.shields.io/badge/Linter-flake8-ff69b4" alt="Linter: flake8" style="max-width: 100%;">
    </a>
    <a href="http://mypy-lang.org">
        <img src="https://img.shields.io/badge/Type_checker-mypy-1674b1" alt="Type checker: mypy" style="max-width: 100%;">
    </a>
    <a href="https://github.com/PyCQA/bandit">
        <img src="https://img.shields.io/badge/Security-bandit-yellow.svg" alt="Security: bandit" style="max-width: 100%;">
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/Code_style-black-black" alt="Code style: black" style="max-width: 100%;">
    </a>
</p>

## Description

Python SMHI (Swedish Meteorological and Hydrological Institute) client.
Currently supports these APIs

- Meteorological Observations Metobs
- Meteorological Forecasts Metfcts
- Meteorological Analysis Mesan
- Meteorological Analysis Strang

## Installation

The package isn't registered and needs to be installed from GitHub

```bash
pip install git+https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi.git@main
```

==> ifk-smhi-0.1.1.tar.gz: ifk-smhi-0.1.1/README.md <==
<h1 align="center">ifk-smhi</h1>

<p align="center">
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml/badge.svg?branch=main" alt="build" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-build.yaml">
        <img src="https://img.shields.io/endpoint?logo=github&labelColor=%23333a41&logoColor=%23959da5&url=https://gist.githubusercontent.com/mgcth/2d8de651f24d184f5ebe101ffc3c9527/raw/ifk-smhi-coverage-badge.json" alt="coverage" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-docs.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-docs.yaml/badge.svg?branch=main" alt="docs" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-lint.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-lint.yaml/badge.svg?branch=main" alt="lint" style="max-width: 100%;">
    </a>
    <a href="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-type.yaml">
        <img src="https://github.com/Ingenjorsarbete-For-Klimatet/ifk-smhi/actions/workflows/github-action-type.yaml/badge.svg?branch=main" alt="type" style="max-width: 100%;">
    </a>
</p>

<p align="center">
    <a href="https://www.python.org">
        <img src="https://img.shields.io/badge/Python-3.9%20|%203.10%20|%203.11-blue" alt="Python: 3.9 | 3.10 | 3.11" style="max-width: 100%;">
    </a>
    <a href="https://pytest.org">
        <img src="https://img.shields.io/badge/Testing_framework-pytest-a04000" alt="Testing framework: pytest" style="max-width: 100%;">
    </a>
    <a href="hhttps://flake8.pycqa.org">
        <img src="https://img.shields.io/badge/Linter-flake8-ff69b4" alt="Linter: flake8" style="max-width: 100%;">
    </a>
    <a href="http://mypy-lang.org">
        <img src="https://img.shields.io/badge/Type_checker-mypy-1674b1" alt="Type checker: mypy" style="max-width: 100%;">
    </a>
    <a href="https://github.com/PyCQA/bandit">
        <img src="https://img.shields.io/badge/Security-bandit-yellow.svg" alt="Security: bandit" style="max-width: 100%;">
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/Code_style-black-black" alt="Code style: black" style="max-width: 100%;">
    </a>
</p>

## Description

Python SMHI (Swedish Meteorological and Hydrological Institute) client.
Currently supports these APIs

- Meteorological Observations Metobs
- Meteorological Forecasts Metfcts
- Meteorological Analysis Mesan
- Meteorological Analysis Strang

## Installation

ifk-smhi can be installed as

```bash
pip install ifk-smhi
```
